## 1.3.0 - 2025-01-22

### ✨ Added

- [#1242](https://github.com/edgarrmondragon/citric/issues/1242) Added survey group ID input parameter to `list_surveys`

### 📚 Documentation

- [#1227](https://github.com/edgarrmondragon/citric/issues/1227) Document usage in R with reticulate

### 🏷️ Typing

- [#1230](https://github.com/edgarrmondragon/citric/issues/1230) Add type annotations for quota language settings and test those attributes

- [#1245](https://github.com/edgarrmondragon/citric/issues/1245) Richer annotation for the return type of `list_surveys`

### 📦 Packaging

- [#1236](https://github.com/edgarrmondragon/citric/issues/1236) Use PEP 639
